==> fantacalciobazar_0.5.2.tar.gz: fantacalciobazar/crea_giornata.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_admin_errata == "NO") {

$lock = fopen("$percorso_cartella_dati/admin.lock","w+");
flock($lock,2);

$num_lettere = strlen($giornata);
if ($num_lettere != 10) $creare = "NO";
if (@is_file("$percorso_cartella_dati/$giornata")) $creare = "NO";

$num_giocatori=count($pass);
$num_giornata = substr($giornata,8);
if (substr($num_giornata,0,1) == 0) $num_giornata = substr($num_giornata,1);
$num_campionati = count($campionato);
reset($campionato);
for($num1 = 0 ; $num1 < $num_campionati; $num1++) {
$key_campionato = key($campionato);
$giornate_campionato = explode("-",$key_campionato);
if ($num_giornata <= $giornate_campionato[1] and $num_giornata >= $giornate_campionato[0]) {
$num_giornata_campionato = $num_giornata - $giornate_campionato[0] + 1;
$tipo_campionato = $campionato[$key_campionato];
break;
} # fine if ($num_giornata <= $giornate_campionato[1] and...
next($campionato);
} # fine for $num1
if (!$tipo_campionato) $tipo_campionato = "N";
if ($tipo_campionato == "S") {
if ($num_giocatori == 4 or $num_giocatori == 6 or $num_giocatori == 8 or $num_giocatori == 10 or $num_giocatori == 12) {
$attiva_scontri_diretti = "SI";
} # fine if ($num_giocatori == 4 or...
else {
echo "Per attivare gli scontri diretti il numero di partecipanti deve essere di 4,6,8,10 o 12.<br>";
$creare = "NO";
} # fine else if ($num_giocatori == 4 or...
} # fine if ($tipo_campionato == "S")


if ($creare == "NO") echo "ERRORE<br>";
else {

#mkdir($giornata, 0777);
#chmod("$giornata", 0777);

$filegiornata = "";
$proprietario = "";
$ruolo  = "";
$nome = "";
$calciatori = file("$percorso_cartella_dati/mercato.txt");
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti < 0) {
$proprietario[$numero] = $dati_calciatore[4];
$ruolo[$numero] = $dati_calciatore[2];
$nome[$numero] = $dati_calciatore[1];
} # fine if ($sec_restanti < 0)
} # fine for $num1

reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
$giocatore_numero[$num1+1] = $giocatore;
$dati_squadra = @file("$percorso_cartella_dati/squadra_$giocatore");
$titolari_veri = "";
$num_titolari_veri = 0;
$panchinari_veri = "";
$num_panchinari_veri = 0;
$titolari = explode(",", $dati_squadra[1]);
$num_titolari = count($titolari);
$panchinari = explode(",", $dati_squadra[2]);
$num_panchinari = count($panchinari);
for ($num2 = 0 ; $num2 < $num_titolari; $num2++) {
$numero_titolare = $titolari[$num2];
$nome_titolare = $nome[$numero_titolare];
$ruolo_titolare = $ruolo[$numero_titolare];
if ($proprietario[$numero_titolare] == $giocatore) {
$titolari_veri .= "$numero_titolare,$nome_titolare,$ruolo_titolare
";
$num_titolari_veri++;
} # fine if ($proprietario[$numero_titolare] == $giocatore)
} # fine for $num2
for ($num2 = 0 ; $num2 < $num_panchinari; $num2++) {
$numero_panchinaro = $panchinari[$num2];
$nome_panchinaro = $nome[$numero_panchinaro];
$ruolo_panchinaro = $ruolo[$numero_panchinaro];
if ($proprietario[$numero_panchinaro] == $giocatore) {
$panchinari_veri .= "$numero_panchinaro,$nome_panchinaro,$ruolo_panchinaro
";
$num_panchinari_veri++;
} # fine if ($proprietario[$numero_titolare] == $giocatore)
} # fine for $num2
if ($num_titolari_veri < $min_num_titolari_in_formazione) {
$titolari_veri = "";
$panchinari_veri = "";
} # fine if ($num_titolari_veri < $min_num_titolari_in_formazione)
if ($num_panchinari_veri > $max_in_panchina) $panchinari_veri = "";
$formazioni .= "#@& formazione #@&
$giocatore
$titolari_veri
$panchinari_veri
";
next($pass);
} # fine for $num1


if ($attiva_scontri_diretti == "SI") {
$file_scontri = file("$percorso_cartella_scontri/squadre$num_giocatori");
$num_linee_file_scontri = count($file_scontri);
$finito_scontri = "NO";
$conta_cicli_while = 0;
while ($finito_scontri != "SI") {
$ultima_giornata = 0;
$inizio_campionato = "";
$campionato_in_corso = "";
$inizio_giornata = "";
$giornata_in_corso = "";
$scontri_diretti = "#@& scontri #@&
";
for ($num1 = 0 ; $num1 < $num_linee_file_scontri; $num1++) {
$linea_file_scontri = togli_acapo($file_scontri[$num1]);
if ($campionato_in_corso == "SI") {
if ($linea_file_scontri == "</campionato>") break;

if ($giornata_in_corso == "SI") {
if ($linea_file_scontri == "</giornata>") break;

$partita = explode("-",$linea_file_scontri);
$squadra1 = $giocatore_numero[$partita[0]];
$squadra2 = $giocatore_numero[$partita[1]];
$scontri_diretti .= $squadra1."##@@&&".$squadra2."
";
} # fine if ($campionato_in_corso == "SI")

if ($inizio_giornata == "SI") {
$inizio_giornata = "";
if ($linea_file_scontri > $ultima_giornata) $ultima_giornata = $linea_file_scontri;
if  ($linea_file_scontri == $num_giornata_campionato) $giornata_in_corso = "SI";
} # fine if ($inizio_campionato)
if ($linea_file_scontri == "<giornata>") $inizio_giornata = "SI";

} # fine if ($campionato_in_corso == "SI")
if ($inizio_campionato == "SI") {
$inizio_campionato = "";
if  ($linea_file_scontri == $num_giocatori) $campionato_in_corso = "SI";
} # fine if ($inizio_campionato)
if ($linea_file_scontri == "<campionato>") $inizio_campionato = "SI";
} # fine for $num1
$scontri_diretti .= "#@& fine scontri #@&
";
if ($giornata_in_corso == "SI" or !$ultima_giornata or $ultima_giornata == 0) $finito_scontri = "SI";
else {
$verifica_num = ereg_replace("[0-9]","",$ultima_giornata);
if ($verifica_num != "") $finito_scontri = "SI";
else $num_giornata_campionato = $num_giornata_campionato - $ultima_giornata;
} # fine else if ($giornata_in_corso == "SI" or ...)
$conta_cicli_while++;
if ($conta_cicli_while >= 500) $finito_scontri = "SI";
} # fine while ($finito_scontri != "SI")
} # fine if ($attiva_scontri_diretti == "SI")


$filegiornata = fopen("$percorso_cartella_dati/$giornata","w+");
fwrite($filegiornata,"#@& data #@&".date("d/m/Y H:i")."
#@& formazioni #@&
$formazioni#@& fine formazioni #@&
");
if ($attiva_scontri_diretti == "SI") {
fwrite($filegiornata,"$scontri_diretti");
} # fine if ($attiva_scontri_diretti == "SI")
fclose($filegiornata);


echo "$giornata creata!<br>";
} # fine else if ($creare == "NO")

flock($lock,3);
fclose($lock);

echo "<form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form>";


} # fine if ($pass_admin_errata == "NO")

include("$percorso_cartella_dati/foot.php");
?>

==> fantacalciobazar_0.5.5.tar.gz: fantacalciobazar/crea_giornata.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include('./include/funzioni.php');
include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_admin_errata == "NO") {

$lock = fopen("$percorso_cartella_dati/admin.lock","w+");
flock($lock,2);

$num_lettere = strlen($giornata);
if ($num_lettere != 10) $creare = "NO";
if (@is_file("$percorso_cartella_dati/$giornata")) $creare = "NO";

$num_giocatori=count($pass);
$num_giornata = substr($giornata,8);
if (substr($num_giornata,0,1) == 0) $num_giornata = substr($num_giornata,1);
$num_campionati = count($campionato);
reset($campionato);
for($num1 = 0 ; $num1 < $num_campionati; $num1++) {
$key_campionato = key($campionato);
$giornate_campionato = explode("-",$key_campionato);
if ($num_giornata <= $giornate_campionato[1] and $num_giornata >= $giornate_campionato[0]) {
$num_giornata_campionato = $num_giornata - $giornate_campionato[0] + 1;
$tipo_campionato = $campionato[$key_campionato];
break;
} # fine if ($num_giornata <= $giornate_campionato[1] and...
next($campionato);
} # fine for $num1
if (!$tipo_campionato) $tipo_campionato = "N";
if ($tipo_campionato == "S") {
if ($num_giocatori == 4 or $num_giocatori == 6 or $num_giocatori == 8 or $num_giocatori == 10 or $num_giocatori == 12) {
$attiva_scontri_diretti = "SI";
} # fine if ($num_giocatori == 4 or...
else {
echo "Per attivare gli scontri diretti il numero di partecipanti deve essere di 4,6,8,10 o 12.<br>";
$creare = "NO";
} # fine else if ($num_giocatori == 4 or...
} # fine if ($tipo_campionato == "S")


if ($creare == "NO") echo "ERRORE<br>";
else {

#mkdir($giornata, 0777);
#chmod("$giornata", 0777);

$filegiornata = "";
$proprietario = array();
$ruolo  = array();
$nome = array();
if (@is_file("$percorso_cartella_dati/mercato.txt")) $calciatori = file("$percorso_cartella_dati/mercato.txt");
else $calciatori = array();
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti < 0) {
$proprietario[$numero] = $dati_calciatore[4];
$ruolo[$numero] = $dati_calciatore[2];
$nome[$numero] = $dati_calciatore[1];
} # fine if ($sec_restanti < 0)
} # fine for $num1

reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
$giocatore_numero[$num1+1] = $giocatore;
$dati_squadra = @file("$percorso_cartella_dati/squadra_$giocatore");
$titolari_veri = "";
$num_titolari_veri = 0;
$panchinari_veri = "";
$num_panchinari_veri = 0;
$titolari = explode(",", $dati_squadra[1]);
$num_titolari = count($titolari);
$panchinari = explode(",", $dati_squadra[2]);
$num_panchinari = count($panchinari);
for ($num2 = 0 ; $num2 < $num_titolari; $num2++) {
$numero_titolare = $titolari[$num2];
$nome_titolare = $nome[$numero_titolare];
$ruolo_titolare = $ruolo[$numero_titolare];
if ($proprietario[$numero_titolare] == $giocatore) {
$titolari_veri .= "$numero_titolare,$nome_titolare,$ruolo_titolare
";
$num_titolari_veri++;
} # fine if ($proprietario[$numero_titolare] == $giocatore)
} # fine for $num2
for ($num2 = 0 ; $num2 < $num_panchinari; $num2++) {
$numero_panchinaro = $panchinari[$num2];
$nome_panchinaro = $nome[$numero_panchinaro];
$ruolo_panchinaro = $ruolo[$numero_panchinaro];
if ($proprietario[$numero_panchinaro] == $giocatore) {
$panchinari_veri .= "$numero_panchinaro,$nome_panchinaro,$ruolo_panchinaro
";
$num_panchinari_veri++;
} # fine if ($proprietario[$numero_titolare] == $giocatore)
} # fine for $num2
if ($num_titolari_veri < $min_num_titolari_in_formazione) {
$titolari_veri = "";
$panchinari_veri = "";
} # fine if ($num_titolari_veri < $min_num_titolari_in_formazione)
if ($num_panchinari_veri > $max_in_panchina) $panchinari_veri = "";
$formazioni .= "#@& formazione #@&
$giocatore
$titolari_veri
$panchinari_veri
";
next($pass);
} # fine for $num1


if ($attiva_scontri_diretti == "SI") {
$file_scontri = file("$percorso_cartella_scontri/squadre$num_giocatori");
$num_linee_file_scontri = count($file_scontri);
$finito_scontri = "NO";
$conta_cicli_while = 0;
while ($finito_scontri != "SI") {
$ultima_giornata = 0;
$inizio_campionato = "";
$campionato_in_corso = "";
$inizio_giornata = "";
$giornata_in_corso = "";
$scontri_diretti = "#@& scontri #@&
";
for ($num1 = 0 ; $num1 < $num_linee_file_scontri; $num1++) {
$linea_file_scontri = togli_acapo($file_scontri[$num1]);
if ($campionato_in_corso == "SI") {
if ($linea_file_scontri == "</campionato>") break;

if ($giornata_in_corso == "SI") {
if ($linea_file_scontri == "</giornata>") break;

$partita = explode("-",$linea_file_scontri);
$squadra1 = $giocatore_numero[$partita[0]];
$squadra2 = $giocatore_numero[$partita[1]];
$scontri_diretti .= $squadra1."##@@&&".$squadra2."
";
} # fine if ($campionato_in_corso == "SI")

if ($inizio_giornata == "SI") {
$inizio_giornata = "";
if ($linea_file_scontri > $ultima_giornata) $ultima_giornata = $linea_file_scontri;
if  ($linea_file_scontri == $num_giornata_campionato) $giornata_in_corso = "SI";
} # fine if ($inizio_campionato)
if ($linea_file_scontri == "<giornata>") $inizio_giornata = "SI";

} # fine if ($campionato_in_corso == "SI")
if ($inizio_campionato == "SI") {
$inizio_campionato = "";
if  ($linea_file_scontri == $num_giocatori) $campionato_in_corso = "SI";
} # fine if ($inizio_campionato)
if ($linea_file_scontri == "<campionato>") $inizio_campionato = "SI";
} # fine for $num1
$scontri_diretti .= "#@& fine scontri #@&
";
if ($giornata_in_corso == "SI" or !$ultima_giornata or $ultima_giornata == 0) $finito_scontri = "SI";
else {
$verifica_num = preg_replace("/[0-9]/","",$ultima_giornata);
if ($verifica_num != "") $finito_scontri = "SI";
else $num_giornata_campionato = $num_giornata_campionato - $ultima_giornata;
} # fine else if ($giornata_in_corso == "SI" or ...)
$conta_cicli_while++;
if ($conta_cicli_while >= 500) $finito_scontri = "SI";
} # fine while ($finito_scontri != "SI")
} # fine if ($attiva_scontri_diretti == "SI")


$filegiornata = fopen("$percorso_cartella_dati/$giornata","w+");
fwrite($filegiornata,"#@& data #@&".date("d/m/Y H:i")."
#@& formazioni #@&
$formazioni#@& fine formazioni #@&
");
if ($attiva_scontri_diretti == "SI") {
fwrite($filegiornata,"$scontri_diretti");
} # fine if ($attiva_scontri_diretti == "SI")
fclose($filegiornata);


echo "$giornata creata!<br>";
} # fine else if ($creare == "NO")

flock($lock,3);
fclose($lock);

echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form>";


} # fine if ($pass_admin_errata == "NO")

include("$percorso_cartella_dati/foot.php");
?>
